#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pgname postgresql15
%if "%{pgname}" == ""
%define pgname postgresql
%endif
# Thanks upstream :-)
%define sname plr
%define sversion REL8_4_6
# Make our path like what postgresql packager decide

%define pgshare %(pg_config --sharedir)
%define pkglibs %(pg_config --pkglibdir)
%define extensiondir %{pgshare}/extension

Summary:        PL/R - R Procedural Language for PostgreSQL
License:        GPL-2.0-or-later
Group:          Productivity/Databases/Servers
Name:           %{pgname}-%{sname}
Version:        8.4.6
Release:        2.3
Source:         https://github.com/postgres-plr/plr/archive/%{sversion}.tar.gz
Source1:        readme.SUSE
Source2:        plr-US.pdf
Source99:       series
Patch0:         patch-Makefile-ldflags.patch
URL:            https://github.com/postgres-plr/plr/
BuildRequires:  %{pgname}-server
BuildRequires:  %{pgname}-server-devel
BuildRequires:  R-base
BuildRequires:  R-base-devel
BuildRequires:  pkg-config
BuildRequires:  post-build-checks
Requires:       %{pgname}-server
Requires:       R-base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if "%{pgname}" == "postgresql"
ExclusiveArch:  do_not_build
%endif
%if ("%{pgname}" == "postgresql95" || "%{pgname}" == "postgresql96") && 0%{?suse_version} >= 1550
ExclusiveArch:  do_not_build
%endif

%description
PL/R is a loadable procedural language that enables you to write PostgreSQL
functions and triggers in the R programming language. PL/R offers most (if
not all) of the capabilities a function writer has in the R language.

Commands are available to access the database via the PostgreSQL Server
Programming Interface (SPI) and to raise messages via elog() . There is no
way to access internals of the database backend. However the user is able
to gain OS-level access under the permissions of the PostgreSQL user ID,
as with a C function. Thus, any unprivileged database user should not be
permitted to use this language. It must be installed as an untrusted
procedural language so that only database superusers can create functions
in it. The writer of a PL/R function must take care that the function cannot
be used to do anything unwanted, since it will be able to do anything that
could be done by a user logged in as the database administrator.

An implementation restriction is that PL/R procedures cannot be used to
create input/output functions for new data types.

%package doc
Summary:        Documentation for PL/R - R Procedural Language for PostgreSQL
Group:          Productivity/Databases/Servers

%description doc
PL/R is a loadable procedural language that enables you to write PostgreSQL
functions and triggers in the R programming language. PL/R offers most (if
not all) of the capabilities a function writer has in the R language.

This package contain the associated documentation

%prep
# plr.so know where R is located
%autosetup -p1 -n %{sname}-%{sversion}

# Need to fix spurious rights in doc and root
find ./ -type f -exec chmod 0644 {} \;
cp -v %{S:2} .

%build
export PATH="$PATH:/usr/lib/%{pgname}/bin"
# Picked from main obs postgresql
export CFLAGS="%optflags $SP"
# uncomment the following line to enable the stack protector
CFLAGS="$CFLAGS -fstack-protector"

#Rpath?
LDFLAGS="$LDFLAGS -Wl,-rpath,%_libdir/R/lib"
USE_PGXS=1 %__make %{?extension} %{?_smp_mflags};

%install
export PATH="$PATH:/usr/lib/%{pgname}/bin"
mkdir -p %{buildroot}/etc/ld.so.conf.d/
# okay keep this method until using rpath is completed
cat  > %{buildroot}/etc/ld.so.conf.d/%{name}.conf <<EOF
# postgresql-plr need to find where R is installed
%{_libdir}/R
%{_libdir}/R/lib
EOF

# All the right location could be found with pg_config
# USE_PGXS=1 make install
install -d -m 0755 %{buildroot}/%{pkglibs}
install -m 755 %{sname}.so %{buildroot}/%{pkglibs}/%{sname}.so
install -d -m 0755 %{buildroot}/%{extensiondir}
install -p -m 644 %{sname}*.sql %{buildroot}%{extensiondir}/
install -p -m 644 %{sname}.control %{buildroot}%{extensiondir}/%{sname}.control

cp -a %{S:1} .

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(644, root, root, 0755)
%doc README.md
%doc readme.SUSE
%dir %{extensiondir}/
%{extensiondir}/%{sname}.control
%{extensiondir}/%{sname}*.sql
%config /etc/ld.so.conf.d/%{name}.conf
%defattr(755, root, root, 0755)
%dir %{pkglibs}
%{pkglibs}/%{sname}.so

%files doc
%defattr(644, root, root, 0755)
%doc *pdf
%doc expected/plr.out

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Jan  8 2024 Bruno Friedmann <bruno@ioda-net.ch>
- update to bugfix release 8.4.6 adding support to postgresql16
  - Refactored AssertArg to Assert
  - Release with R version 4.1.3 and 4.2.3
- update copyright notice
- remove postgresql11 build
* Thu Sep 28 2023 Marcus Rueckert <mrueckert@suse.de>
- enable pg 16
* Wed Apr 19 2023 Reinhard Max <max@suse.com>
- PostgreSQL 10 is EOL.
* Tue Jan 31 2023 Marcus Rueckert <mrueckert@suse.de>
- refresh patch-Makefile-ldflags.patch
* Tue Jan 31 2023 Marcus Rueckert <mrueckert@suse.de>
- enable pg 13 and 14
* Tue Jan 31 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 8.4.5
  - added sql upgrade path to fix
- changes from 8.4.4
  - changed files names to be consistent with extension version
- changes from 8.4.3
  - reverted part of PR#88. postgres has reverted the changes to
    hex_decode that made it necessary (#120)
- changes from 8.4.2
  - Changed R version to 4.10.
  - Added support for transactions in procedures. @petere
  - Added support for pg custom type (tuple) arguments in window
    functions
* Wed Jun 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build postgresql95 and postgresql96 flavors on Tumbleweed.
* Fri Sep 25 2020 Marcus Rueckert <mrueckert@suse.de>
- enable pg 13
* Fri Sep 25 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 8.4.1
  - Accept composite argument type. [@ikasou]
  - Internal change to postgres api required code change. No
    noticeable change to users
  - R can pass to PG arrays of any dimensions.
  - Major duplicate code removal in R to PG conversion.
- refreshed patch-Makefile-ldflags.patch
* Tue Jun  9 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Drop postgresql94 flavor: pgsql94 is EOL.
* Tue Oct 22 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 8.4
  - Use 8.4 in plr.control (#61)
  - Remove unused testing files Those were to be used with PG < 9.x
- refreshed patch-Makefile-ldflags.patch
* Tue Oct 22 2019 Marcus Rueckert <mrueckert@suse.de>
- adding postgresql12 to _multibuild
* Sat Oct 27 2018 Marcus Rueckert <mrueckert@suse.de>
- refresh patch-Makefile-ldflags.patch to apply cleanly again
* Sat Oct 27 2018 Marcus Rueckert <mrueckert@suse.de>
- update to 08.03.00.18
  Due to some minor changes in the internal API, there were some
  small changes in the source to accommodate the changes.
* Thu Oct 25 2018 Reinhard Max <max@suse.com>
- Add build for PostgreSQL 11 and drop 9.3.
- BuildRequire server-devel instead of devel.
* Thu Aug 10 2017 mrueckert@suse.de
- use _multibuild
* Tue Jul 25 2017 bruno@ioda-net.ch
- Packaging
  + Make comment versionable
  + Remove obsoleted macro (mkdir, install)
  + Fix copyright line
* Wed Jul 12 2017 bruno@ioda-net.ch
- Remove non maintained postgresql version 9.1 9.2
* Sat Jan 14 2017 bruno@ioda-net.ch
- Undo the rename of postgresql-plr.changes.in to make happy
  factory auto-bot
* Wed Jan 11 2017 bruno@ioda-net.ch
- Update to 08.03.00.17 version - Bring support to postgresql96
- Packaging
  + Move source to github and adapt packaging for that
  + Add plr-US.pdf as documentation, html being not delivered
    Documentation is build outside of the package to avoid texlive
  + Redone patch-Makefile-ldflags.patch to current sources
  + Rename postgresql-plr.changes.in to postgresql-plr.changes to
    ease osc vc edition, adapt pre_checking.sh to this change.
* Mon Dec 21 2015 bruno@ioda-net.ch
- Fix postun/postin ldconfig call (see comment in sr#345782)
* Fri Feb 13 2015 bruno@ioda-net.ch
- Update to last upstream tar.gz
  Due to missing root plr, and documentation (Conway)
- Removed upgrade alter extension, this doesn't work yet
* Mon Feb  9 2015 bruno@ioda-net.ch
- Update to upstream 8.3.0.16
  Update for PostgreSQL 9.5dev compatibility
  Update copyrights
  Add check and throw an error when don't have an expectedDesc.
  Remove autocommit setting -- it has been removed in PostgreSQL
  9.5, and it has been ineffective for a long time.
    Reported by Peter E.
  Fix RPM spec file (redhat)
- Added support to postgresql94 packages
- modified patches: redone for 8.0.16
  * patch-Makefile-ldflags.patch
* Thu Jan 23 2014 bruno@ioda-net.ch
- Revised year
- Added pre_checkin.sh methode to create variant packages
* Fri Dec  6 2013 bruno@ioda-net.ch
- Update to upstream 8.0.15
  Update for PostgreSQL 9.3 compatibility
  Ensure certain errors in R code do not crash postgres
  Unbreak compilation with older versions of postgres not having rangetypes
  Allow use of OUT parameters
- modified patches: redone for 8.0.15
  * patch-Makefile-ldflags.patch
* Mon Nov 18 2013 bruno@ioda-net.ch
- Packaging postgresql-plr
  Added postgresql-server as BuildRequires so rpmlint doesn't complain about
  owner of postgresql base install directory
* Fri Sep 27 2013 bruno@ioda-net.ch
- split postgresql-plr to postgresql version aligned
  postgresql91-plr linked to postgresql91
  postgresql92-plr linked to postgresql92
  postgresql93-plr linked to postgresql93
* Wed Jul 24 2013 bruno@ioda-net.ch
- Upgrade to 8.3.0.14
  Update copyright for 2013
  Remove hack to take signal back from R interpreter (Mark Kirkwood)
  Set R_SignalHandlers = 0, the proper way to prevent R from taking signals in the first place (Mark Kirkwood)
  Adjust RPM spec file
  As of pg9.2 the syntax "LANGUAGE 'C'" no longer works. Use "LANGUAGE C" instead.
  The MacPorts installation has the header filed distributed across two different directories, so there is no single "rincludedir" to query from pkg-config. Instead, do it the proper way and ask pkg-config for the cflags, which should work for all installation variants. (Peter Eisentraut)
* Wed Jan  2 2013 darin@darins.net
  * Upgrade to 8.3.0.13.1
  - Fix CREATE FUNCTION statements so that they work
  with PostgreSQL 9.2.x
* Mon Apr 16 2012 bruno@ioda-net.ch
- Make factory happy added R-base as Build-Require
* Sun Apr  1 2012 bruno@ioda-net.ch
- Fix formatting & licence scheme
* Fri Mar 30 2012 bruno@ioda-net.ch
- Fix installation directory : goes to extension now
- Added missing expected plr.out to doc as sample howto
* Sat Mar  3 2012 bruno@ioda-net.ch
- Split documentation to postgresql-plr
- Add more informations (first step and test to readme.SUSE)
- Try to use -rpath (following darix advise) but no success
* Mon Oct 17 2011 bruno@ioda-net.ch
  * Upgrade to 8.3.0.13
  - Fix Makefile so that msvc scripts can process it successfully
  - Add support for pgsql 9.1 CREATE EXTENSION
  - Put in safeguard to prevent attempted return of non-data (e.g.
  closure) types from R unless the pg return type is BYTEA
  - Correct thinko from earlier pass-by-val array optimization
  - Fix crashbug related to conversion of R data.frame to Postgres
  array on function return
  - Add plr_version() function: outputs a version string
  - New feature: allow PL/R functions to be declared and used
  as WINDOW functions
  - Minor fixes for compiler warnings by updated gcc
  - Fix missing calls to UNPROTECT. Report and patch by Ben Leiting.
  - Take SIGINT back into Postgres control from R. Report and test case
  by Terry Schmitt.
  - Don't try to free an array element value when the array element is NULL
  - Allow pg.spi.prepare/pg.spi.execp to use parameters which are 1D arrays-
* Fri Jun 17 2011 bruno@ioda-net.ch
- Fixed spurious perms
* Mon Jun 13 2011 bruno@ioda-net.ch
- Try to fix folders installation
* Wed Jun  8 2011 bruno@ioda-net.ch
- First spec version for obs
